


package org.softevo.oumextractor.controlflow;



import java.util.Collections;
import java.util.Map;
import java.util.Set;

import org.softevo.oumextractor.analysis.Analyzer;
import org.softevo.oumextractor.analysis.Frame;



/**
 * This class is used to represent normal exit node in a control flow graph.
 * 
 * @author Andrzej Wasylkowski
 */
public final class ExitNode extends Node {

	/**
	 * Creates new exit node.
	 */
	public ExitNode () {
	}
	
	
	
	/**
	 * Creates a deep copy of given node.
	 * @param other	Node to be copied.
	 */
	public ExitNode (ExitNode other) {
		super (other);
	}
	
	
	
	/* (non-Javadoc)
	 * @see org.softevo.oumextractor.controlflow.Node#getOut()
	 */
	@Override
	public Frame getOut () {
		return null;
	}



	/* (non-Javadoc)
	 * @see org.softevo.oumextractor.controlflow.Node#copyNormalPath(java.util.Map)
	 */
	@Override
	public Node copyNormalPath (Map<Node, Node> copies) {
		// if the copy exists, return it
		if (copies.containsKey (this)) {
			return copies.get (this);
		}
		
		// copy a path beginning at this node
		ExitNode result = new ExitNode (this);
		copies.put (this, result);
		return result;
	}
	
	
	
	/* (non-Javadoc)
	 * @see org.softevo.oumextractor.controlflow.Node#getAllSuccessors()
	 */
	@Override
	public Set<Node> getAllSuccessors () {
		return Collections.emptySet ();
	}
	
	
	
	/* (non-Javadoc)
	 * @see org.softevo.oumextractor.controlflow.Node#getAllDataflowSuccessors()
	 */
	@Override
	public Set<Node> getAllDataflowSuccessors () {
		return getAllSuccessors ();
	}

	
	
	/* (non-Javadoc)
	 * @see org.softevo.oumextractor.controlflow.Node#analyzeDataFlow(org.softevo.oumextractor.analysis.Analyzer)
	 */
	@Override
	public void analyzeDataFlow (Analyzer analyzer) {
	}
	
	
	
	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString () {
		return "ExitNode";
	}
}
